import React, { useCallback, useState } from 'react';
import { connect, history } from 'umi';
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import { PlusOutlined } from '@ant-design/icons';
import { Button, Popconfirm, Image, Space, notification } from 'antd';
import request, { queryTable } from '@/utils/request';

const typeList = { post: '科普' };
// const stateList = { post: '科普' };

const BannerList = () => {
  const [, setLoading] = useState(false);
  const handleBannerClick = useCallback((id) => {
    history.push(id ? `/cms/banner/edit?id=${id}` : '/cms/banner/edit');
  }, []);

  const actions = [
    <Button key="button" icon={<PlusOutlined />} type="primary" onClick={() => handleBannerClick()}>
      新建
    </Button>,
  ];

  const deleteBannerClick = (id) => {
    setLoading(true);

    request(`/banner/${id}`, { method: 'delete' })
      .then(() => {
        notification.success({ message: '删除成功' });
        // ref.current.submit();
      })
      .catch((e) => {
        setLoading(false);
        notification.error({ message: e.message });
      });
  };

  const columns = [
    {
      title: '排序',
      dataIndex: 'sort',
      width: 60,
      hideInSearch: true,
      align: 'center',
    },
    {
      title: '主图',
      dataIndex: 'image',
      hideInSearch: true,

      align: 'center',
      render: (text) => <Image width={64} height={64} src={text} />,
    },
    {
      title: '名称',
      dataIndex: 'title',
      align: 'center',
      className: 'drag-visible',
    },
    {
      title: '板块',
      dataIndex: 'targetType',
      hideInSearch: true,
      align: 'center',
      render: (text) => typeList[text] || '',
    },

    {
      title: '状态',
      dataIndex: 'status',
      align: 'center',
      hideInSearch: true,
      // render: (text) => <Image src={text} />,
    },
    {
      title: '操作',
      dataIndex: 'action',
      align: 'center',
      hideInSearch: true,
      render: (text, record) => (
        <Space size="middle">
          <a onClick={() => handleBannerClick(record.serialNo)}>编辑</a>
          <Popconfirm
            key="popconfirm"
            title={`确认删除吗?`}
            onConfirm={() => deleteBannerClick(record.serialNo)}
            okText="是"
            cancelText="否"
          >
            <a>删除</a>
          </Popconfirm>
        </Space>
      ),
    },
  ];

  return (
    <PageContainer>
      <ProTable
        columns={columns}
        request={queryTable('/school')}
        rowKey="schoolId"
        headerTitle="学校列表"
        search={{
          labelWidth: '4em',
        }}
        toolBarRender={() => actions}
      />
    </PageContainer>
  );
};

export default connect((s) => ({
  typeList: s.post.typeList,
}))(BannerList);
